@@ -21,7 +21,7 @@
 
 class SkinSettings : public SkinSettingsUI
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 
     public:
