@@ -35,7 +35,7 @@ class TDEPopupMenu;
 
 class TabbedWidget : public TranslucentWidget
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 
     public:
