@@ -19,7 +19,7 @@
 
 class TerminalFocusWatcher : public TQObject
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 
     public:
